@@ -12,7 +12,7 @@
 ## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with this program.  If not, see <http://www.gnu.org/licenses/>.
+## along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 library("SimInf")
 
@@ -269,7 +269,7 @@ model@events@select <- rep(1:4, length.out = length(model@events@select))
 
 # Check that this fails because rownames (compartments) are missing
 res <- tools::assertError(run(model, threads = 1))
-stopifnot(length(grep("'S' and 'E' must have identical compartments",
+stopifnot(length(grep("'S' and 'E' must have rownames matching the compartments.",
                       res[[1]]$message)) > 0)
 
 rownames(model@events@E) <- c("S", "E", "I", "R")
