@@ -1,7 +1,7 @@
 ## SimInf, a framework for stochastic disease spread simulations
 ## Copyright (C) 2015  Pavol Bauer
-## Copyright (C) 2015 - 2018  Stefan Engblom
-## Copyright (C) 2015 - 2018  Stefan Widgren
+## Copyright (C) 2015 - 2019  Stefan Engblom
+## Copyright (C) 2015 - 2019  Stefan Widgren
 ##
 ## This program is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
 ## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with this program.  If not, see <http://www.gnu.org/licenses/>.
+## along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 library("SimInf")
 
@@ -1072,8 +1072,8 @@ stopifnot(all(abs(traj_observed[, 5] - traj_expected$phi) < 1e-8))
 
 ## Specify invalid formula
 res <- tools::assertError(trajectory(result, ~1))
-stopifnot(length(grep("Invalid formula specification of 'compartments'",
-                      res[[1]]$message)) > 0)
+stopifnot(length(grep("Non-existing compartment(s) in model: '1'",
+                      res[[1]]$message, fixed = TRUE)) > 0)
 
 ## Check SISe plot method
 pdf_file <- tempfile(fileext = ".pdf")
