@@ -1,6 +1,6 @@
 ## SimInf, a framework for stochastic disease spread simulations
-## Copyright (C) 2015 - 2018  Stefan Engblom
-## Copyright (C) 2015 - 2018  Stefan Widgren
+## Copyright (C) 2015 - 2019  Stefan Engblom
+## Copyright (C) 2015 - 2019  Stefan Widgren
 ##
 ## This program is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
 ## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with this program.  If not, see <http://www.gnu.org/licenses/>.
+## along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 library("SimInf")
 
@@ -1004,6 +1004,25 @@ res <- tools::assertError(SISe_sp(u0       = u0,
 stopifnot(length(grep("The 'distance' argument must be of type 'dgCMatrix'",
                       res[[1]]$message)) > 0)
 
+## Check that non-data.frame u0 works
+SISe_sp(u0       = cbind(S = 0:8, I = rep(0, 9)),
+        tspan    = seq_len(10) - 1,
+        events   = NULL,
+        phi      = rep(0, 9),
+        upsilon  = 0.0357,
+        gamma    = 0.1,
+        alpha    = 1.0,
+        beta_t1  = 0.19,
+        beta_t2  = 0.085,
+        beta_t3  = 0.075,
+        beta_t4  = 0.185,
+        end_t1   = 91,
+        end_t2   = 182,
+        end_t3   = 273,
+        end_t4   = 365,
+        coupling = 0.0005,
+        distance = distance)
+
 ## Check extraction of data from 'suscpetible', and 'infected'
 ## compartments
 model <- SISe_sp(u0       = u0,
